@@ -44,9 +44,9 @@ sub grep {
 	my @grepped_points = (); ### these are scheduled for deletion
 
 	for (my $i = 0; $i < length(@rgbasl); $i++) {
-		if (@rgbasl[$i]->{index - $self->{imgrepr}->{width}} ~~ @indexl
-			and @rgbasl[$i]->{index - $self->{imgrepr}->{width} - 1} ~~ @indexl
-			and @rgbasl[$i]->{index - $self->{imgrepr}->{width} + 1} ~~ @indexl) {
+		if (@rgbasl[$i]->{@rgbasl[$i]->{index} - $self->{imgrepr}->{width}} ~~ @indexl
+			and @rgbasl[$i]->{@rgbasl[$i]->{index} - $self->{imgrepr}->{width} - 1} ~~ @indexl
+			and @rgbasl[$i]->{@rgbasl[$i]->{index} - $self->{imgrepr}->{width} + 1} ~~ @indexl) {
 		push (@grepped_points, @rgbasl[$i]);
 		}
 	}
