@@ -5,7 +5,7 @@ package GFX::Enhancer::SingleLineEnhancer;
 sub new {
 	my ($class) = @_;
 
-	my $self = { lines_points = (), adjacent_lines_points = (), }; ### lines_points are enhanced, adjacent_lines_points are all neighbourhood points
+	my $self = { lines_points => (), adjacent_lines_points => (), }; ### lines_points are enhanced, adjacent_lines_points are all neighbourhood points
 
 	$class = ref($class) || $class;
 
@@ -19,7 +19,7 @@ sub filter {
 
 	for (my $i = 0; $i < length($imgrepr->{points}); $i++) {
 		if (my @rgbasl = $self->investigate_neighbourhood_of_points($i, $imgrepr, GFX::Enhancer::PointsInvestigator->new)) {
-			push($self->{adjacent_lines_points}, @rgbasl);
+			push(@{ $self->{adjacent_lines_points}}, @rgbasl);
 			$i += length(@rgbasl); ### extraneous points added to
 		}
 	}
